---
comments: true
---

# PaddleX时序异常检测任务模块数据标注教程

时序异常检测是一个无监督学习任务，因此不需要标注训练数据。收集的训练样本尽可能保证都是正常数据，即没有异常（用0表示无异常），训练集中表示异常的标签列均设置为 0，或者不设置标签列也是可以的。验证集为了评估模型精度，需要进行标注，对于在某个时间点是异常的点，将该时间点的标签设置为 1 即可，其他正常的时间点的标签为设置为0。
